//package com.prolog.cs.biz.outbound.service.impl;
//
//import com.alibaba.fastjson.JSON;
//import com.netflix.hystrix.strategy.concurrency.HystrixRequestContext;
//import com.prolog.cs.biz.inbound.dto.IsSuperviseDTO;
//import com.prolog.cs.biz.outbound.dao.PickTaskDMapper;
//import com.prolog.cs.biz.outbound.model.dto.check.CheckConfirmDTO;
//import com.prolog.cs.biz.outbound.model.dto.check.CheckMakeRedDTO;
//import com.prolog.cs.biz.outbound.model.vo.check.InnerCheckTaskDVO;
//import com.prolog.cs.biz.outbound.resource.InBoundClient;
//import com.prolog.framework.authority.util.HystrixVarUtil;
//import com.prolog.framework.common.message.RestMessage;
//import org.junit.After;
//import org.junit.Before;
//import org.junit.Test;
//import org.junit.runner.RunWith;
//import org.springframework.beans.BeanUtils;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.boot.test.context.SpringBootTest;
//import org.springframework.test.context.junit4.SpringRunner;
//import org.springframework.test.context.web.WebAppConfiguration;
//
//import java.math.BigDecimal;
//import java.util.List;
//import java.util.stream.Collectors;
//
//@RunWith(SpringRunner.class)
//@SpringBootTest
//@WebAppConfiguration
//public class InnerCheckServiceImplTest {
//
//    @Autowired
//    private InnerCheckServiceImpl InnerCheckServiceImpl;
//
//    @Autowired
//    InBoundClient inBoundClient;
//
//    @Autowired
//    PickTaskDMapper pickTaskDMapper;
//
//    @Before
//    public void before() throws Exception {
//        HystrixRequestContext context = HystrixRequestContext.initializeContext();
//        HystrixVarUtil.setUserKey("kzywms-admin");
//    }
//
//    @After
//    public void after() throws Exception {
//    }
//
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.init()));
//    public void testInit() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.getCurrentContainer()));
//    public void testGetCurrentContainer() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.updatePickupStatusFunc()));
//    public void testUpdatePickupStatusFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.findPickupByContainerFunc()));
//    public void testFindPickupByContainerFunc() throws Exception {
//        System.out.println(JSON.toJSONString(InnerCheckServiceImpl.findPickupByContainerFunc(
//                "237","FH2-01","724997161347059712")));
//
////        List<InnerCheckTaskDVO> pickTasks = pickTaskDMapper.getPickTaskd("711910431430275072",false);
////        pickTasks = pickTasks.stream().filter(x -> x.getPickQty() != null).collect(Collectors.toList());
////        //阶段：0=入库质检 1=PC拣货 2=PC内复核 3=PC外复核 4=补录 5=PDA拣货 6=PDA内复核 7=PDA外复核
////        if(pickTasks!=null && pickTasks.size()>0){
////            try {
////                RestMessage<List<? extends IsSuperviseDTO>> rest = inBoundClient.isSupervise(pickTasks, 2);
////                if (rest.isSuccess() && rest.getData() != null && rest.getData().size() == pickTasks.size()) {
////                    for (int i = 0; i < rest.getData().size(); i++) {
////                        BeanUtils.copyProperties(rest.getData().get(i), pickTasks.get(i));
////                    }
////                }
////                System.out.println(JSON.toJSONString(rest));
////            } catch (Exception e) {
////                //log.error("调用监管码接口异常", e);
////            }
////        }
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.updateLcl()));
//    public void testUpdateLcl() throws Exception {
//        InnerCheckServiceImpl.
//                updateLcl("720279518237036544","720279518237036544","720279518237036544",
//                        new BigDecimal("2"),"720279518237036544","720279518237036544",
//                        2,"599581702716788736");
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.updateLclQtyTemp()));
//    public void testUpdateLclQtyTemp() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.getContainersInfo()));
//    public void testGetContainersInfo() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.printLcl()));
//    public void testPrintLcl() throws Exception {
//        System.out.println(JSON.toJSONString(
//                //InnerCheckServiceImpl.printLcl("30005077","SKPQUC00256174","1")));
//                //InnerCheckServiceImpl.printLcl("31","ZHY13000008","1")));
//                InnerCheckServiceImpl.printLcl("35","ZHY13000022","1")));
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.validPrintLclFunc()));
//    public void testValidPrintLclFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.printLclFunc()));
//    public void testPrintLclFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.queryLcl()));
//    public void testQueryLcl() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.makeCheckRed()));
//    public void testMakeCheckRed() throws Exception {
//        String s="{\"billGroupId\":\"SJ1060000151\",\"containerCode\":\"237\",\"itemBarcode\":\"202104250005\",\"lclNo\":\"\",\"pickTaskDId\":\"724997161347059712\",\"qty\":1,\"stationCode\":\"FH2-01\",\"userNames\":[null],\"workCode\":\"00000001\",\"warehouseId\":\"599581702716788736\",\"itemCode\":\"YP107281\",\"redReason\":\"12\",\"redQty\":\"12\",\"redDoMethod\":\"1\",\"userId\":\"\",\"username\":\"00000001\",\"billId\":\"724997003658006528\",\"billDId\":\"724997003699949568\",\"srcId\":\"SJ1060000151\",\"srcLineId\":\"SJ1060000151\"}";
//        CheckMakeRedDTO redDTO=JSON.parseObject(s,CheckMakeRedDTO.class);
//        System.out.println(JSON.toJSONString(InnerCheckServiceImpl.makeCheckRed(redDTO)));
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.validRedFunc()));
//    public void testValidRedFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.redFunc()));
//    public void testRedFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.lclAdjust()));
//    public void testLclAdjust() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.pieceBreak()));
//    public void testPieceBreak() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.validCaseSplitFunc()));
//    public void testValidCaseSplitFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.caseSplitBoxFunc()));
//    public void testCaseSplitBoxFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.lclDelete()));
//    public void testLclDelete() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.printLclDetail()));
//    public void testPrintLclDetail() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.validPrintBoxDetailFunc()));
//    public void testValidPrintBoxDetailFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.checkItemByNum()));
//    public void testCheckItemByNum() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.checkItem()));
//    public void testCheckItem() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.validInnerCheckFunc()));
//    public void testValidInnerCheckFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.updatePickupDInnerCheckInfoFunc()));
//    public void testUpdatePickupDInnerCheckInfoFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.createBarcodeFunc()));
//    public void testCreateBarcodeFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.pickTaskDCheckConfirm()));
//    public void testPickTaskDCheckConfirm() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.addLcl()));
//    public void testAddLcl() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.validLCLFunc()));
//    public void testValidLCLFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.lclFunc()));
//    public void testLclFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.getItemInfo()));
//    public void testGetItemInfo() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.containerCheckConfirm()));
//    public void testContainerCheckConfirm() throws Exception {
//        CheckConfirmDTO checkConfirmDTO=new CheckConfirmDTO();
//        checkConfirmDTO.setContainerCode("30000696");
//        checkConfirmDTO.setBillGroupId("SKPQUC00256089");
//        checkConfirmDTO.setStationCode("FH2-01");
//        System.out.println(JSON.toJSONString(InnerCheckServiceImpl.containerCheckConfirm(checkConfirmDTO)));
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.validInnerCheckConfirmFunc()));
//    public void testValidInnerCheckConfirmFunc() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckServiceImpl.innerCheckConfirmFunc()));
//    public void testInnerCheckConfirmFunc() throws Exception {
//
//    }
//
//}
